logo
pub enum Cli {
    Validator {
        config: PathBuf,
        config_ext: Vec<ConfigExt>,
    },
    MigrateConfig {
        old_config: PathBuf,
        new_config: PathBuf,
    },
    MigrateData {
        old_config: PathBuf,
        new_config: PathBuf,
    },
}
Casper blockchain node.

Variants

Validator

Fields

config: PathBuf

Path to configuration file.

config_ext: Vec<ConfigExt>

Overrides and extensions for configuration file entries in the form

.=. For example, '-C=node.chainspec_config_path=chainspec.toml'

Run the validator node.

Loads the configuration values from the given configuration file or uses defaults if not given, then runs the reactor.

MigrateConfig

Fields

old_config: PathBuf

Path to configuration file of previous version of node.

new_config: PathBuf

Path to configuration file of this version of node.

Migrate modified values from the old config as required after an upgrade.

MigrateData

Fields

old_config: PathBuf

Path to configuration file of previous version of node.

new_config: PathBuf

Path to configuration file of this version of node.

Migrate any stored data as required after an upgrade.

Implementations

Executes selected CLI command.