Module casper_node::components[][src]

Components

Components are the building blocks of the whole application, wired together inside a reactor. Each component has a unified interface, expressed by the Component trait.

Modules

Contract Runtime component.

Traits

Core Component.