Enum casper_node::components::contract_runtime::ContractRuntimeResult[][src]

pub enum ContractRuntimeResult {
    GetDeploysResult {
        finalized_block: FinalizedBlock,
        deploys: VecDeque<Deploy>,
    },
    GetParentResult {
        finalized_block: FinalizedBlock,
        deploys: VecDeque<Deploy>,
        parent: Option<(BlockHash, Digest, Digest)>,
    },
    RunStepResult {
        state: Box<RequestState>,
        result: Result<StepResult, Error>,
    },
    ExecutedAndCommitted(Box<RequestState>),
}
Contract runtime component event.

Variants

GetDeploysResult

Received all requested deploys.

Fields of GetDeploysResult

finalized_block: FinalizedBlock

The block that needs the deploys for execution.

deploys: VecDeque<Deploy>

Contents of deploys. All deploys are expected to be present in the storage component.

GetParentResult

Received a parent result.

Fields of GetParentResult

finalized_block: FinalizedBlock

The block that needs the deploys for execution.

deploys: VecDeque<Deploy>

Contents of deploys. All deploys are expected to be present in the storage component.

parent: Option<(BlockHash, Digest, Digest)>

Parent of the newly finalized block. If it’s the first block after Genesis then parent is None.

RunStepResult

The result of running the step on a switch block.

Fields of RunStepResult

state: Box<RequestState>

State of this request.

result: Result<StepResult, Error>

The result.

ExecutedAndCommitted(Box<RequestState>)

Once a block is executed and committed, re-enter evented flow.