Module casper_node::crypto[][src]

Cryptographic types and functions.

Modules

Cryptographic hash type and function.

Enums

Cryptographic errors.

Traits

Additional operations an asymmetric key

Functions

Generates an Ed25519 keypair using the operating system’s cryptographically secure random number generator.

Signs the given message using the given key pair.

Verifies the signature of the given message against the given public key.

Type Definitions

A specialized std::result::Result type for cryptographic errors.