[][src]Enum casper_node::crypto::asymmetric_key::SecretKey

pub enum SecretKey {
    Ed25519(SecretKey),
    Secp256k1(SecretKey),
}

A secret or private asymmetric key.

Variants

Ed25519(SecretKey)

Ed25519 secret key.

Secp256k1(SecretKey)

secp256k1 secret key.

Implementations

impl SecretKey[src]

pub const ED25519_LENGTH: usize[src]

The length in bytes of an Ed25519 secret key.

pub const SECP256K1_LENGTH: usize[src]

The length in bytes of a secp256k1 secret key.

pub fn new_ed25519(bytes: [u8; 32]) -> Self[src]

Constructs a new Ed25519 variant from a byte array.

pub fn new_secp256k1(bytes: [u8; 32]) -> Self[src]

Constructs a new secp256k1 variant from a byte array.

pub fn ed25519_from_bytes<T: AsRef<[u8]>>(bytes: T) -> Result<Self>[src]

Constructs a new Ed25519 variant from a byte slice.

pub fn secp256k1_from_bytes<T: AsRef<[u8]>>(bytes: T) -> Result<Self>[src]

Constructs a new secp256k1 variant from a byte slice.

pub fn generate_ed25519() -> Self[src]

Constructs a new Ed25519 variant using the operating system's cryptographically secure random number generator.

pub fn generate_secp256k1() -> Self[src]

Constructs a new secp256k1 variant using the operating system's cryptographically secure random number generator.

pub fn as_secret_slice(&self) -> &[u8][src]

Exposes the secret values of the key as a byte slice.

pub fn to_file<P: AsRef<Path>>(&self, file: P) -> Result<()>[src]

Attempts to write the secret key bytes to the configured file path.

pub fn from_file<P: AsRef<Path>>(file: P) -> Result<Self>[src]

Attempts to read the secret key bytes from configured file path.