[][src]Enum casper_node::crypto::asymmetric_key::Signature

pub enum Signature {
    Ed25519([u8; 64]),
    Secp256k1(Secp256k1Signature),
}

A signature of given data.

Variants

Ed25519([u8; 64])

Ed25519 signature.

secp256k1 signature.

Implementations

impl Signature[src]

pub const ED25519_LENGTH: usize[src]

The length in bytes of an Ed25519 signature,

pub const SECP256K1_LENGTH: usize[src]

The length in bytes of a secp256k1 signature

pub fn new_ed25519(bytes: [u8; 64]) -> Result<Self>[src]

Constructs a new Ed25519 variant from a byte array.

pub fn new_secp256k1(bytes: [u8; 64]) -> Result<Self>[src]

Constructs a new secp256k1 variant from a byte array.

pub fn ed25519_from_bytes<T: AsRef<[u8]>>(bytes: T) -> Result<Self>[src]

Constructs a new Ed25519 variant from a byte slice.

pub fn secp256k1_from_bytes<T: AsRef<[u8]>>(bytes: T) -> Result<Self>[src]

Constructs a new secp256k1 variant from a byte slice.

pub fn to_hex(&self) -> String[src]

Converts the signature to hex, where the first byte represents the algorithm tag.

pub fn from_hex<T: AsRef<[u8]>>(input: T) -> Result<Self>[src]

Tries to decode a signature from its hex-representation. The hex format should be as produced by Signature::to_hex().