[−][src]Enum casper_node::effect::requests::ApiRequest
Abstract API request.
An API request is an abstract request that does not concern itself with serialization or transport.
Variants
Submit a deploy to be announced.
Fields of SubmitDeploy
If maybe_hash is Some, return the specified block if it exists, else None. If
maybe_hash is None, return the latest block.
Fields of GetBlock
maybe_id: Option<BlockIdentifier>The hash of the block to be retrieved.
responder: Responder<Option<LinearBlock>>Responder to call with the result.
Query the global state at the given root hash.
Fields of QueryGlobalState
Query the global state at the given root hash.
Fields of QueryEraValidators
state_root_hash: DigestThe global state hash.
protocol_version: ProtocolVersionThe protocol version.
responder: Responder<Result<EraValidators, GetEraValidatorsError>>Responder to call with the result.
Query the contract runtime for protocol version data.
Fields of QueryProtocolData
protocol_version: ProtocolVersionThe protocol version.
responder: Responder<Result<Option<Box<ProtocolData>>, Error>>Responder to call with the result.
Query the global state at the given root hash.
Fields of GetBalance
Return the specified deploy and metadata if it exists, else None.
Fields of GetDeploy
hash: DeployHashThe hash of the deploy to be retrieved.
responder: Responder<Option<(Deploy, DeployMetadata<LinearBlock>)>>Responder to call with the result.
Return the connected peers.
Fields of GetPeers
responder: Responder<HashMap<I, SocketAddr>>Responder to call with the result.
Return string formatted status or None if an error occurred.
Fields of GetStatus
responder: Responder<StatusFeed<I>>Responder to call with the result.
Return string formatted, prometheus compatible metrics or None if an error occurred.