[][src]Enum casper_node::effect::requests::BlockProposerRequest

#[must_use]pub enum BlockProposerRequest {
    ListForInclusion {
        current_instant: Timestamp,
        past_blocks: HashSet<ProtoBlockHash>,
        responder: Responder<HashSet<DeployHash>>,
    },
}

A BlockProposer request.

Variants

ListForInclusion

Request a list of deploys to propose in a new block.

Fields of ListForInclusion

current_instant: Timestamp

The instant for which the deploy is requested.

past_blocks: HashSet<ProtoBlockHash>

Set of block hashes pointing to blocks whose deploys should be excluded.

responder: Responder<HashSet<DeployHash>>

Responder to call with the result.