Enum casper_node::effect::requests::RpcRequest[][src]

pub enum RpcRequest<I> {
    SubmitDeploy {
        deploy: Box<Deploy>,
        responder: Responder<Result<(), Error>>,
    },
    GetBlock {
        maybe_id: Option<BlockIdentifier>,
        responder: Responder<Option<(LinearBlock, BlockSignatures)>>,
    },
    GetBlockTransfers {
        block_hash: BlockHash,
        responder: Responder<Option<Vec<Transfer>>>,
    },
    QueryGlobalState {
        state_root_hash: Digest,
        base_key: Key,
        path: Vec<String>,
        responder: Responder<Result<QueryResult, Error>>,
    },
    QueryEraValidators {
        state_root_hash: Digest,
        protocol_version: ProtocolVersion,
        responder: Responder<Result<EraValidators, GetEraValidatorsError>>,
    },
    GetBids {
        state_root_hash: Digest,
        responder: Responder<Result<GetBidsResult, Error>>,
    },
    QueryProtocolData {
        protocol_version: ProtocolVersion,
        responder: Responder<Result<Option<Box<ProtocolData>>, Error>>,
    },
    GetBalance {
        state_root_hash: Digest,
        purse_uref: URef,
        responder: Responder<Result<BalanceResult, Error>>,
    },
    GetDeploy {
        hash: DeployHash,
        responder: Responder<Option<(Deploy, DeployMetadata)>>,
    },
    GetPeers {
        responder: Responder<BTreeMap<I, String>>,
    },
    GetStatus {
        responder: Responder<StatusFeed<I>>,
    },
    GetMetrics {
        responder: Responder<Option<String>>,
    },
}
Abstract RPC request.

An RPC request is an abstract request that does not concern itself with serialization or transport.

Variants

SubmitDeploy

Submit a deploy to be announced.

Fields of SubmitDeploy

deploy: Box<Deploy>

The deploy to be announced.

responder: Responder<Result<(), Error>>

Responder to call.

GetBlock

If maybe_identifier is Some, return the specified block if it exists, else None. If maybe_identifier is None, return the latest block.

Fields of GetBlock

maybe_id: Option<BlockIdentifier>

The identifier (can either be a hash or the height) of the block to be retrieved.

responder: Responder<Option<(LinearBlock, BlockSignatures)>>

Responder to call with the result.

GetBlockTransfers

Return transfers for block by hash (if any).

Fields of GetBlockTransfers

block_hash: BlockHash

The hash of the block to retrieve transfers for.

responder: Responder<Option<Vec<Transfer>>>

Responder to call with the result.

QueryGlobalState

Query the global state at the given root hash.

Fields of QueryGlobalState

state_root_hash: Digest

The state root hash.

base_key: Key

Hex-encoded casper_types::Key.

path: Vec<String>

The path components starting from the key as base.

responder: Responder<Result<QueryResult, Error>>

Responder to call with the result.

QueryEraValidators

Query the global state at the given root hash.

Fields of QueryEraValidators

state_root_hash: Digest

The global state hash.

protocol_version: ProtocolVersion

The protocol version.

responder: Responder<Result<EraValidators, GetEraValidatorsError>>

Responder to call with the result.

GetBids

Get the bids at the given root hash.

Fields of GetBids

state_root_hash: Digest

The global state hash.

responder: Responder<Result<GetBidsResult, Error>>

Responder to call with the result.

QueryProtocolData

Query the contract runtime for protocol version data.

Fields of QueryProtocolData

protocol_version: ProtocolVersion

The protocol version.

responder: Responder<Result<Option<Box<ProtocolData>>, Error>>

Responder to call with the result.

GetBalance

Query the global state at the given root hash.

Fields of GetBalance

state_root_hash: Digest

The state root hash.

purse_uref: URef

The purse URef.

responder: Responder<Result<BalanceResult, Error>>

Responder to call with the result.

GetDeploy

Return the specified deploy and metadata if it exists, else None.

Fields of GetDeploy

hash: DeployHash

The hash of the deploy to be retrieved.

responder: Responder<Option<(Deploy, DeployMetadata)>>

Responder to call with the result.

GetPeers

Return the connected peers.

Fields of GetPeers

responder: Responder<BTreeMap<I, String>>

Responder to call with the result.

GetStatus

Return string formatted status or None if an error occurred.

Fields of GetStatus

responder: Responder<StatusFeed<I>>

Responder to call with the result.

GetMetrics

Return string formatted, prometheus compatible metrics or None if an error occurred.

Fields of GetMetrics

responder: Responder<Option<String>>

Responder to call with the result.