Struct casper_node::effect::EffectBuilder [−][src]
pub struct EffectBuilder<REv: 'static>(_);
A builder for Effects.
Provides methods allowing the creation of effects which need to be scheduled on the reactor’s event queue, without giving direct access to this queue.
Implementations
Creates a new effect builder.
Run and end effect immediately.
Can be used to trigger events from effects when combined with .event. Do not use this to
“do nothing”, as it will still cause a task to be spawned.
Reports a fatal error. Normally called via the crate::fatal!() macro.
Usually causes the node to cease operations quickly and exit/crash.
Broadcasts a network message.
Broadcasts a network message to all peers connected at the time the message is sent.
pub async fn gossip_message<I, P>(
self,
payload: P,
count: usize,
exclude: HashSet<I>
) -> HashSet<I> where
REv: From<NetworkRequest<I, P>>,
I: Send + 'static,
P: Send,
pub async fn gossip_message<I, P>(
self,
payload: P,
count: usize,
exclude: HashSet<I>
) -> HashSet<I> where
REv: From<NetworkRequest<I, P>>,
I: Send + 'static,
P: Send, Gossips a network message.
A low-level “gossip” function, selects count randomly chosen nodes on the network,
excluding the indicated ones, and sends each a copy of the message.
Returns the IDs of the chosen nodes.
pub async fn network_peers<I>(self) -> BTreeMap<I, String> where
REv: From<NetworkInfoRequest<I>>,
I: Send + 'static,
pub async fn network_peers<I>(self) -> BTreeMap<I, String> where
REv: From<NetworkInfoRequest<I>>,
I: Send + 'static, Gets connected network peers.