[−][src]Enum casper_node::reactor::QueueKind
Scheduling priority.
Priorities are ordered from lowest to highest.
Variants
Network events that were initiated outside of this node.
Their load may vary and grouping them together in one queue aides DoS protection.
Network events that were initiated by the local node, such as outgoing messages.
Events of unspecified priority.
This is the default queue.
Reporting events on the local node.
Metric events take precedence over most other events since missing a request for metrics might cause the requester to assume that the node is down and forcefully restart it.