[][src]Struct casper_node::reactor::joiner::Reactor

pub struct Reactor { /* fields omitted */ }

Joining node reactor.

Implementations

impl Reactor[src]

pub async fn into_validator_config(self) -> ValidatorInitConfig[src]

Deconstructs the reactor into config useful for creating a Validator reactor. Shuts down the network, closing all incoming and outgoing connections, and frees up the listening socket.