Struct casper_node::reactor::Runner[][src]

pub struct Runner<R> where
    R: Reactor
{ /* fields omitted */ }
A runner for a reactor.

The runner manages a reactors event queue and reactor itself and can run it either continuously or in a step-by-step manner.

Implementations

Creates a new runner from a given configuration.

Creates a metrics registry that is only going to be used in this runner.

Creates a new runner from a given configuration, using existing metrics.

Processes a single event on the event queue.

Returns false if processing should stop.

Runs the reactor until maybe_exit() returns Some or we get interrupted by a termination signal.

Returns a reference to the reactor.

Returns a mutable reference to the reactor.

Shuts down a reactor, sealing and draining the entire queue before returning it.