Type Definition casper_node::reactor::Scheduler[][src]

pub type Scheduler<Ev> = WeightedRoundRobin<Ev, QueueKind>;
Event scheduler

The scheduler is a combination of multiple event queues that are polled in a specific order. It is the central hook for any part of the program that schedules events directly.

Components rarely use this, but use a bound EventQueueHandle instead.