logo
pub enum Error {
Show 18 variants CreateDatabaseDirectory(PathBufError), DuplicateBlockIndex { height: u64, first: BlockHash, second: BlockHash, }, DuplicateEraIdIndex { era_id: EraId, first: BlockHash, second: BlockHash, }, DuplicateDeployIndex { deploy_hash: DeployHash, first: BlockHash, second: BlockHash, }, InternalStorage(LmdbExtError), UnableToMoveFile { source_path: PathBuf, dest_path: PathBuf, original_error: Error, }, MissingStorageFiles { missing_files: Vec<PathBuf>, }, BlockValidation(BlockValidationError), BlockHeaderNotStoredUnderItsHash { queried_block_hash_bytes: Vec<u8>, found_block_header_hash: BlockHash, block_header: Box<BlockHeader>, }, NoBlockHeaderForBlockBody { block_body_hash: Digest, hashing_algorithm_version: HashingAlgorithmVersion, block_body: Box<BlockBody>, }, UnexpectedHashingAlgorithmVersion { expected_hashing_algorithm_version: HashingAlgorithmVersion, actual_hashing_algorithm_version: HashingAlgorithmVersion, }, CouldNotFindBlockBodyPart { block_hash: BlockHash, merkle_linked_list_node_hash: Digest, }, SignatureVerification(Error), CorruptedBlockSignatureIndex { raw_key: Vec<u8>, block_hash_bytes: Vec<u8>, }, NonExistentBlockBodyReferredToByHeader(Box<BlockHeader>), NonExistentDeploy { deploy_hash: DeployHash, block: Box<Block>, }, UnexpectedBlockBodyPart { block_body_hash: Digest, part_hash: Digest, }, UnexpectedFinalizedApprovals { deploy_hash: DeployHash, },
}
A storage component error.

Variants

CreateDatabaseDirectory(PathBufError)

Failure to create the root database directory.

DuplicateBlockIndex

Fields

height: u64

Height at which duplicate was found.

first: BlockHash

First block hash encountered at height.

second: BlockHash

Second block hash encountered at height.

Found a duplicate block-at-height index entry.

DuplicateEraIdIndex

Fields

era_id: EraId

Era ID at which duplicate was found.

first: BlockHash

First block hash encountered at era_id.

second: BlockHash

Second block hash encountered at era_id.

Found a duplicate switch-block-at-era-id index entry.

DuplicateDeployIndex

Fields

deploy_hash: DeployHash

Deploy hash at which duplicate was found.

first: BlockHash

First block hash encountered at deploy_hash.

second: BlockHash

Second block hash encountered at deploy_hash.

Found a duplicate switch-block-at-era-id index entry.

InternalStorage(LmdbExtError)

LMDB error while operating.

UnableToMoveFile

Fields

source_path: PathBuf

The path to the file that should have been moved.

dest_path: PathBuf

The path where the file should have been moved to.

original_error: Error

The original io::Error from fs::rename.

Filesystem error while trying to move file.

MissingStorageFiles

Fields

missing_files: Vec<PathBuf>

The files that were not be found in the storage directory.

Mix of missing and found storage files.

BlockValidation(BlockValidationError)

Error when validating a block.

BlockHeaderNotStoredUnderItsHash

Fields

queried_block_hash_bytes: Vec<u8>

The queried block hash.

found_block_header_hash: BlockHash

The actual header of the block hash.

block_header: Box<BlockHeader>

The block header found in storage.

A block header was not stored under its hash.

NoBlockHeaderForBlockBody

Fields

block_body_hash: Digest

The block body hash.

hashing_algorithm_version: HashingAlgorithmVersion

The hashing algorithm of the block body.

block_body: Box<BlockBody>

The block body.

Block body did not have a block header.

UnexpectedHashingAlgorithmVersion

Fields

expected_hashing_algorithm_version: HashingAlgorithmVersion

Expected hashing algorithm version.

actual_hashing_algorithm_version: HashingAlgorithmVersion

Actual hashing algorithm version.

Unexpected hashing algorithm version.

CouldNotFindBlockBodyPart

Fields

block_hash: BlockHash

The block hash queried.

merkle_linked_list_node_hash: Digest

The hash of the node in the Merkle linked list.

Could not find block body part.

SignatureVerification(Error)

Could not verify finality signatures for block.

CorruptedBlockSignatureIndex

Fields

raw_key: Vec<u8>

The key in the block signature index.

block_hash_bytes: Vec<u8>

The block hash of the signatures found in the index.

Corrupted block signature index.

NonExistentBlockBodyReferredToByHeader(Box<BlockHeader>)

Non-existent block body referred to by header.

NonExistentDeploy

Fields

deploy_hash: DeployHash

The missing deploy hash.

block: Box<Block>

The block which has the missing deploy hash.

Non-existent deploy or transfer in block.

UnexpectedBlockBodyPart

Fields

block_body_hash: Digest

The block body with the issue.

part_hash: Digest

The hash of the superfluous body part.

A block body was found to have more parts than expected.

UnexpectedFinalizedApprovals

Fields

deploy_hash: DeployHash

The missing deploy hash.

We tried to store finalized approvals for a nonexistent deploy.