Struct casper_node::storage::Storage
source · [−]pub struct Storage { /* private fields */ }Expand description
Storage component.
Implementations
sourceimpl Storage
impl Storage
sourcepub fn new(
cfg: &WithDir<Config>,
hard_reset_to_start_of_era: Option<EraId>,
protocol_version: ProtocolVersion,
should_check_integrity: bool,
network_name: &str
) -> Result<Self, Error>
pub fn new(
cfg: &WithDir<Config>,
hard_reset_to_start_of_era: Option<EraId>,
protocol_version: ProtocolVersion,
should_check_integrity: bool,
network_name: &str
) -> Result<Self, Error>
Creates a new storage component.
If should_check_integrity is true, time-consuming integrity checks will be performed
during this call to new(), potentially blocking for several minutes. This should normally
only be required if the node is detected to have restarted after a crash.
sourcepub fn put_deploy(&self, deploy: &Deploy) -> Result<bool, Error>
pub fn put_deploy(&self, deploy: &Deploy) -> Result<bool, Error>
Put a single deploy into storage.
sourcepub fn read_block(&self, block_hash: &BlockHash) -> Result<Option<Block>, Error>
pub fn read_block(&self, block_hash: &BlockHash) -> Result<Option<Block>, Error>
Retrieves a block by hash.
sourcepub fn read_deploy_by_hash(
&self,
deploy_hash: DeployHash
) -> Result<Option<Deploy>, Error>
pub fn read_deploy_by_hash(
&self,
deploy_hash: DeployHash
) -> Result<Option<Deploy>, Error>
Directly returns a deploy from internal store.
sourcepub fn write_block(&mut self, block: &Block) -> Result<bool, Error>
pub fn write_block(&mut self, block: &Block) -> Result<bool, Error>
Writes a block to storage, updating indices as necessary
Returns Ok(true) if the block has been successfully written, Ok(false) if a part of it
couldn’t be written because it already existed, and Err(_) if there was an error.
sourcepub fn read_block_by_height(&self, height: u64) -> Result<Option<Block>, Error>
pub fn read_block_by_height(&self, height: u64) -> Result<Option<Block>, Error>
Retrieves single block by height by looking it up in the index and returning it.
sourcepub fn store_finalized_approvals(
&self,
deploy_hash: &DeployHash,
finalized_approvals: &FinalizedApprovals
) -> Result<(), Error>
pub fn store_finalized_approvals(
&self,
deploy_hash: &DeployHash,
finalized_approvals: &FinalizedApprovals
) -> Result<(), Error>
Stores a set of finalized approvals.