[−][src]Enum casper_node::tls::ValidationError
Error during certificate validation.
Variants
CannotReadPublicKey(ErrorStack)Failed to read public key from certificate.
CorruptSubjectOrIssuer(ErrorStack)Failed to read subject or issuer name.
Wrong signature scheme.
TimeIssue(ErrorStack)Failed to read or convert times.
Certificate not yet valid.
Certificate expired.
InvalidSerialNumber(ErrorStack)Serial number could not be compared to the reference.
Wrong serial number.
CouldNotExtractEcKey(ErrorStack)No valid elliptic curve key could be extracted from certificate.
KeyFailsCheck(ErrorStack)Public key failed sanity check.
Wrong elliptic curve.
Certificate not self-signed.
FailedToValidateSignature(ErrorStack)Failed to validate signature.
Invalid signature.
InvalidFingerprint(ErrorStack)Invalid fingerprint.
BigNumContextNotAvailable(ErrorStack)Failed to create a big num context.
PublicKeyEncodingFailed(ErrorStack)Failed to encode public key.