logo
The chainspec is a set of configuration options for the network. All validators must apply the same set of options in order to join and act as a peer in a given network.

Structs

A collection of configuration settings describing the state of the system at genesis and after upgrades to basic system functionality occurring after genesis.

Enums

Error returned by the ChainspecLoader.

Constants

The name of the chainspec file on disk.