logo
pub enum DeployConfigurationFailure {
Show 17 variants InvalidChainName { expected: String, got: String, }, ExcessiveDependencies { max_dependencies: u8, got: usize, }, ExcessiveSize(ExcessiveSizeError), ExcessiveTimeToLive { max_ttl: TimeDiff, got: TimeDiff, }, InvalidBodyHash, InvalidDeployHash, EmptyApprovals, InvalidApproval { index: usize, error_msg: String, }, ExcessiveSessionArgsLength { max_length: usize, got: usize, }, ExcessivePaymentArgsLength { max_length: usize, got: usize, }, MissingPaymentAmount, FailedToParsePaymentAmount, ExceededBlockGasLimit { block_gas_limit: u64, got: U512, }, MissingTransferAmount, FailedToParseTransferAmount, InsufficientTransferAmount { minimum: U512, attempted: U512, }, ExcessiveApprovals { got: u32, max_associated_keys: u32, },
}
A representation of the way in which a deploy failed validation checks.

Variants

InvalidChainName

Fields

expected: String

The expected chain name.

got: String

The received chain name.

Invalid chain name.

ExcessiveDependencies

Fields

max_dependencies: u8

The dependencies limit.

got: usize

The actual number of dependencies provided.

Too many dependencies.

ExcessiveSize(ExcessiveSizeError)

Deploy is too large.

ExcessiveTimeToLive

Fields

max_ttl: TimeDiff

The time-to-live limit.

got: TimeDiff

The received time-to-live.

Excessive time-to-live.

InvalidBodyHash

The provided body hash does not match the actual hash of the body.

InvalidDeployHash

The provided deploy hash does not match the actual hash of the deploy.

EmptyApprovals

The deploy has no approvals.

InvalidApproval

Fields

index: usize

The index of the approval at fault.

error_msg: String

The approval validation error.

Invalid approval.

ExcessiveSessionArgsLength

Fields

max_length: usize

The byte size limit of session arguments.

got: usize

The received length of session arguments.

Excessive length of deploy’s session args.

ExcessivePaymentArgsLength

Fields

max_length: usize

The byte size limit of payment arguments.

got: usize

The received length of payment arguments.

Excessive length of deploy’s payment args.

MissingPaymentAmount

Missing payment “amount” runtime argument.

FailedToParsePaymentAmount

Failed to parse payment “amount” runtime argument.

ExceededBlockGasLimit

Fields

block_gas_limit: u64

Configured block gas limit.

got: U512

The payment amount received.

The payment amount associated with the deploy exceeds the block gas limit.

MissingTransferAmount

Missing payment “amount” runtime argument

FailedToParseTransferAmount

Failed to parse transfer “amount” runtime argument.

InsufficientTransferAmount

Fields

minimum: U512

The minimum transfer amount.

attempted: U512

The attempted transfer amount.

Insufficient transfer amount.

ExcessiveApprovals

Fields

got: u32

Number of approvals on the deploy.

max_associated_keys: u32

The chainspec limit for max_associated_keys.

The amount of approvals on the deploy exceeds the max_associated_keys limit.