Enum casper_node::types::DeployValidationFailure[][src]

pub enum DeployValidationFailure {
    InvalidChainName {
        expected: String,
        got: String,
    },
    ExcessiveDependencies {
        max_dependencies: u8,
        got: usize,
    },
    ExcessiveSize(ExcessiveSizeError),
    ExcessiveTimeToLive {
        max_ttl: TimeDiff,
        got: TimeDiff,
    },
    InvalidBodyHash,
    InvalidDeployHash,
    InvalidApproval {
        index: usize,
        error_msg: String,
    },
    ExcessiveSessionArgsLength {
        max_length: usize,
        got: usize,
    },
    ExcessivePaymentArgsLength {
        max_length: usize,
        got: usize,
    },
    MissingTransferAmount,
    InvalidTransferAmount,
    InsufficientTransferAmount {
        minimum: U512,
        attempted: U512,
    },
}
A representation of the way in which a deploy failed validation checks.

Variants

InvalidChainName

Invalid chain name.

Fields of InvalidChainName

expected: String

The expected chain name.

got: String

The received chain name.

ExcessiveDependencies

Too many dependencies.

Fields of ExcessiveDependencies

max_dependencies: u8

The dependencies limit.

got: usize

The actual number of dependencies provided.

ExcessiveSize(ExcessiveSizeError)

Deploy is too large.

ExcessiveTimeToLive

Excessive time-to-live.

Fields of ExcessiveTimeToLive

max_ttl: TimeDiff

The time-to-live limit.

got: TimeDiff

The received time-to-live.

InvalidBodyHash

The provided body hash does not match the actual hash of the body.

InvalidDeployHash

The provided deploy hash does not match the actual hash of the deploy.

InvalidApproval

Invalid approval.

Fields of InvalidApproval

index: usize

The index of the approval at fault.

error_msg: String

The approval validation error.

ExcessiveSessionArgsLength

Excessive length of deploy’s session args.

Fields of ExcessiveSessionArgsLength

max_length: usize

The byte size limit of session arguments.

got: usize

The received length of session arguments.

ExcessivePaymentArgsLength

Excessive length of deploy’s payment args.

Fields of ExcessivePaymentArgsLength

max_length: usize

The byte size limit of payment arguments.

got: usize

The received length of payment arguments.

MissingTransferAmount

Missing transfer amount.

InvalidTransferAmount

Invalid transfer amount.

InsufficientTransferAmount

Insufficient transfer amount.

Fields of InsufficientTransferAmount

minimum: U512

The minimum transfer amount.

attempted: U512

The attempted transfer amount.