Enum casper_node::types::ExitCode
source · [−]#[repr(u8)]
pub enum ExitCode {
Success,
Abort,
DowngradeVersion,
SigInt,
SigQuit,
SigTerm,
}Expand description
Exit codes which should be used by the casper-node binary, and provided by the initializer reactor to the binary.
Note that a panic will result in the Rust process producing an exit code of 101.
Variants
Success
The process should exit with success. The launcher should proceed to run the next
installed version of casper-node.
Abort
The process should exit with 101, equivalent to panicking. The launcher should not
restart the node.
DowngradeVersion
The process should exit with 102. The launcher should proceed to run the previous
installed version of casper-node.
SigInt
The exit code Rust uses by default when interrupted via an INT signal.
SigQuit
The exit code Rust uses by default when interrupted via a QUIT signal.
SigTerm
The exit code Rust uses by default when interrupted via a TERM signal.