logo
Types which are serializable to JSON, which map to types defined outside this module.

Structs

Structure representing a user’s account, stored in global state.

Data structure summarizing auction contract data.

A contract struct that can be serialized as JSON object.

Contract definition, metadata, and security container.

Enums

Representation of a value stored in global state.

Functions

A helper function to change NamedKeys into a Vec