Struct casper_node::types::BlockBody
source · [−]pub struct BlockBody { /* private fields */ }Expand description
The body portion of a block.
Implementations
sourceimpl BlockBody
impl BlockBody
sourcepub const PARTS_COUNT: usize = 3usize
pub const PARTS_COUNT: usize = 3usize
The number of parts of a block body.
sourcepub fn merklize(&self) -> MerkleBlockBody<'_>
pub fn merklize(&self) -> MerkleBlockBody<'_>
Constructs the block body hashes for the block body.
sourcepub fn hash(&self, version: HashingAlgorithmVersion) -> Digest
pub fn hash(&self, version: HashingAlgorithmVersion) -> Digest
Computes the block body hash, using the indicated hashing algorithm version.