Struct casper_node::types::Deploy
source · [−]pub struct Deploy { /* private fields */ }Expand description
A deploy; an item containing a smart contract along with the requester’s signature(s).
Implementations
sourceimpl Deploy
impl Deploy
sourcepub fn new(
timestamp: Timestamp,
ttl: TimeDiff,
gas_price: u64,
dependencies: Vec<DeployHash>,
chain_name: String,
payment: ExecutableDeployItem,
session: ExecutableDeployItem,
secret_key: &SecretKey,
account: Option<PublicKey>
) -> Deploy
pub fn new(
timestamp: Timestamp,
ttl: TimeDiff,
gas_price: u64,
dependencies: Vec<DeployHash>,
chain_name: String,
payment: ExecutableDeployItem,
session: ExecutableDeployItem,
secret_key: &SecretKey,
account: Option<PublicKey>
) -> Deploy
Constructs a new signed Deploy.
sourcepub fn sign(&mut self, secret_key: &SecretKey)
pub fn sign(&mut self, secret_key: &SecretKey)
Adds a signature of this deploy’s hash to its approvals.
sourcepub fn id(&self) -> &DeployHash
pub fn id(&self) -> &DeployHash
Returns the DeployHash identifying this Deploy.
sourcepub fn header(&self) -> &DeployHeader
pub fn header(&self) -> &DeployHeader
Returns a reference to the DeployHeader of this Deploy.
sourcepub fn take_header(self) -> DeployHeader
pub fn take_header(self) -> DeployHeader
Returns the DeployHeader of this Deploy.
sourcepub fn payment(&self) -> &ExecutableDeployItem
pub fn payment(&self) -> &ExecutableDeployItem
Returns the ExecutableDeployItem for payment code.
sourcepub fn session(&self) -> &ExecutableDeployItem
pub fn session(&self) -> &ExecutableDeployItem
Returns the ExecutableDeployItem for session code.
sourcepub fn deploy_or_transfer_hash(&self) -> DeployOrTransferHash
pub fn deploy_or_transfer_hash(&self) -> DeployOrTransferHash
Returns the hash of this deploy wrapped in DeployOrTransferHash.
sourcepub fn deploy_info(&self) -> Result<DeployInfo, Error>
pub fn deploy_info(&self) -> Result<DeployInfo, Error>
Returns the DeployInfo.
sourcepub fn is_valid_size(
&self,
max_deploy_size: u32
) -> Result<(), ExcessiveSizeError>
pub fn is_valid_size(
&self,
max_deploy_size: u32
) -> Result<(), ExcessiveSizeError>
Returns true if the serialized size of the deploy is not greater than max_deploy_size.
sourcepub fn is_valid(&mut self) -> Result<(), DeployConfigurationFailure>
pub fn is_valid(&mut self) -> Result<(), DeployConfigurationFailure>
Returns true if and only if:
- the deploy hash is correct (should be the hash of the header), and
- the body hash is correct (should be the hash of the body), and
- approvals are non empty, and
- all approvals are valid signatures of the deploy hash
sourcepub fn is_config_compliant(
&self,
chain_name: &str,
config: &DeployConfig,
max_associated_keys: u32
) -> Result<(), DeployConfigurationFailure>
pub fn is_config_compliant(
&self,
chain_name: &str,
config: &DeployConfig,
max_associated_keys: u32
) -> Result<(), DeployConfigurationFailure>
Returns true if and only if:
- the chain_name is correct,
- the configured parameters are complied with,