Struct casper_node::types::DeployMetadata
source · [−]pub struct DeployMetadata {
pub execution_results: HashMap<BlockHash, ExecutionResult>,
}Expand description
The deploy mutable metadata.
Currently a stop-gap measure to associate an immutable deploy with additional metadata. Holds execution results.
Fields
execution_results: HashMap<BlockHash, ExecutionResult>The block hashes of blocks containing the related deploy, along with the results of executing the related deploy in the context of one or more blocks.