logo
pub struct DeployWithFinalizedApprovals { /* private fields */ }
A deploy combined with a potential set of finalized approvals.

Represents a deploy, along with a potential set of approvals different from those contained in the deploy itself. If such a set of approvals is present, it indicates that the set contained the deploy was not the set used to validate the execution of the deploy after consensus.

A typical case where these can differ is if a deploy is sent with an original set of approvals to the local node, while a second set of approvals makes it to the proposing node. The local node has to adhere to the proposer’s approvals to obtain the same outcome.

Implementations

Creates a new deploy with finalized approvals from parts.

Creates a naive deploy by potentially substituting the approvals with the finalized approvals.

Extracts the original deploy by discarding the finalized approvals.