pub struct NodeConfig {
pub trusted_hash: Option<BlockHash>,
pub sync_handling: SyncHandling,
pub idle_tolerance: TimeDiff,
pub max_attempts: usize,
pub control_logic_default_delay: TimeDiff,
pub force_resync: bool,
pub shutdown_for_upgrade_timeout: TimeDiff,
pub upgrade_timeout: TimeDiff,
pub prevent_validator_shutdown: bool,
}Expand description
Node fast-sync configuration.
Fields
trusted_hash: Option<BlockHash>Hash used as a trust anchor when joining, if any.
sync_handling: SyncHandlingWhich historical sync option? Genesis: sync all the way back to genesis Ttl: sync the necessary number of historical blocks to satisfy TTL requirement. NoSync: don’t attempt to get any historical records; i.e. go forward only.
idle_tolerance: TimeDiffIdle time after which the syncing process is considered stalled.
max_attempts: usizeWhen the syncing process is considered stalled, it’ll be retried up to max_attempts
times.
control_logic_default_delay: TimeDiffDefault delay for the control events that have no dedicated delay requirements.
force_resync: boolFlag which forces the node to resync all of the blocks.
shutdown_for_upgrade_timeout: TimeDiffShutdown for upgrade state timeout, after which the node will upgrade regardless whether all the conditions are satisfied.
upgrade_timeout: TimeDiffMaximum time a node will wait for an upgrade to commit.
prevent_validator_shutdown: boolIf true, prevents a node from shutting down if it is supposed to be a validator in the era.