Module casper_node::utils::ds[][src]

Datasize helper functions.

Functions

Estimate memory usage of a hashmap of keys and values each with no heap allocations.

Estimate memory usage of a hashset of items with no heap allocations.

Extrapolate memory usage of a HashMap by from a random subset of SAMPLE_SIZE items.

Estimate memory usage of a vec of items with no heap allocations.

Extrapolate memory usage of a Vec by from a random subset of SAMPLE_SIZE items.