Function casper_node::utils::ds::vec_fixed_size [−][src]
pub fn vec_fixed_size<T>(vec: &Vec<T>) -> usize
Estimate memory usage of a vec of items with no heap allocations.
pub fn vec_fixed_size<T>(vec: &Vec<T>) -> usize
Estimate memory usage of a vec of items with no heap allocations.