Module casper_node::contract_runtime
source · [−]Expand description
Contract Runtime component.
Structs
A Block that was the result of execution in the ContractRuntime along with any execution
effects it may have.
State to use to construct the next block in the blockchain. Includes the state root hash for the execution engine as well as certain values the next header will be based on.
Functions
Executes a finalized block.