Module casper_node::effect::requests [−][src]
Request effects.
Requests typically ask other components to perform a service and report back the result. See the top-level module documentation for details.
Structs
Details of a request for a list of deploys to propose in a new block.
A block validator request.
Enums
A BlockProposer request.
ChainspecLoader component requests.
Consensus component requests.
A contract runtime request.
Fetcher related requests.
Requests issued to the Linear Chain component.
A metrics request.
A networking info request.
A networking request.
Abstract REST request.
Abstract RPC request.
State store request.
A storage request.