Enum casper_node::effect::requests::ContractRuntimeRequest [−][src]
pub enum ContractRuntimeRequest {
Show 14 variants
ExecuteBlock(FinalizedBlock),
GetProtocolData {
protocol_version: ProtocolVersion,
responder: Responder<Result<Option<Box<ProtocolData>>, Error>>,
},
CommitGenesis {
chainspec: Arc<Chainspec>,
responder: Responder<Result<GenesisResult, Error>>,
},
Upgrade {
upgrade_config: Box<UpgradeConfig>,
responder: Responder<Result<UpgradeResult, Error>>,
},
Query {
query_request: QueryRequest,
responder: Responder<Result<QueryResult, Error>>,
},
GetBalance {
balance_request: BalanceRequest,
responder: Responder<Result<BalanceResult, Error>>,
},
GetEraValidators {
request: EraValidatorsRequest,
responder: Responder<Result<EraValidators, GetEraValidatorsError>>,
},
GetValidatorWeightsByEraId {
request: ValidatorWeightsByEraIdRequest,
responder: Responder<Result<Option<ValidatorWeights>, GetEraValidatorsError>>,
},
GetBids {
get_bids_request: GetBidsRequest,
responder: Responder<Result<GetBidsResult, Error>>,
},
Step {
step_request: StepRequest,
responder: Responder<Result<StepResult, Error>>,
},
IsBonded {
state_root_hash: Digest,
public_key: PublicKey,
era_id: EraId,
protocol_version: ProtocolVersion,
responder: Responder<Result<bool, GetEraValidatorsError>>,
},
ReadTrie {
trie_key: Blake2bHash,
responder: Responder<Option<Trie<Key, StoredValue>>>,
},
PutTrie {
trie: Box<Trie<Key, StoredValue>>,
responder: Responder<Result<Vec<Blake2bHash>, Error>>,
},
MissingTrieKeys {
trie_key: Blake2bHash,
responder: Responder<Result<Vec<Blake2bHash>, Error>>,
},
}Expand description
A contract runtime request.
Variants
A request to execute a block.
Get ProtocolData by ProtocolVersion.
Fields of GetProtocolData
protocol_version: ProtocolVersionThe protocol version.
responder: Responder<Result<Option<Box<ProtocolData>>, Error>>Responder to call with the result.
Commit genesis chainspec.
Fields of CommitGenesis
A request to run upgrade.
Fields of Upgrade
upgrade_config: Box<UpgradeConfig>Upgrade config.
responder: Responder<Result<UpgradeResult, Error>>Responder to call with the upgrade result.
A query request.
Fields of Query
query_request: QueryRequestQuery request.
responder: Responder<Result<QueryResult, Error>>Responder to call with the query result.
A balance request.
Fields of GetBalance
balance_request: BalanceRequestBalance request.
responder: Responder<Result<BalanceResult, Error>>Responder to call with the balance result.
Returns validator weights.
Fields of GetEraValidators
request: EraValidatorsRequestGet validators weights request.
responder: Responder<Result<EraValidators, GetEraValidatorsError>>Responder to call with the result.
Returns validator weights for given era.
Fields of GetValidatorWeightsByEraId
request: ValidatorWeightsByEraIdRequestGet validators weights request.
responder: Responder<Result<Option<ValidatorWeights>, GetEraValidatorsError>>Responder to call with the result.
Return bids at a given state root hash
Fields of GetBids
get_bids_request: GetBidsRequestGet bids request.
responder: Responder<Result<GetBidsResult, Error>>Responder to call with the result.
Performs a step consisting of calculating rewards, slashing and running the auction at the end of an era.
Fields of Step
step_request: StepRequestThe step request.
responder: Responder<Result<StepResult, Error>>Responder to call with the result.
Check if validator is bonded in the future era (identified by era_id).
Fields of IsBonded
state_root_hash: DigestState root hash of the LFB.
public_key: PublicKeyValidator public key.
era_id: EraIdEra ID in which validator should be bonded in.
protocol_version: ProtocolVersionProtocol version at the state_root_hash.
responder: Responder<Result<bool, GetEraValidatorsError>>Responder,
Read a trie by its hash key
Fields of ReadTrie
trie_key: Blake2bHashThe hash of the value to get from the TrieStore
responder: Responder<Option<Trie<Key, StoredValue>>>Responder to call with the result.
Insert a trie into global storage
Fields of PutTrie
trie: Box<Trie<Key, StoredValue>>The hash of the value to get from the TrieStore
responder: Responder<Result<Vec<Blake2bHash>, Error>>Responder to call with the result.
Get the missing keys under a given trie key in global storage
Fields of MissingTrieKeys
trie_key: Blake2bHashThe ancestral hash to use when finding hashes that are missing from the TrieStore
responder: Responder<Result<Vec<Blake2bHash>, Error>>Responder to call with the result.