Enum casper_node::effect::requests::StorageRequest [−][src]
#[repr(u8)]
pub enum StorageRequest {
Show 22 variants
PutBlock {
block: Box<Block>,
responder: Responder<bool>,
},
GetBlock {
block_hash: BlockHash,
responder: Responder<Option<Block>>,
},
GetBlockHeaderAtHeight {
height: u64,
responder: Responder<Option<BlockHeader>>,
},
GetBlockAtHeight {
height: u64,
responder: Responder<Option<Block>>,
},
GetHighestBlock {
responder: Responder<Option<Block>>,
},
GetSwitchBlockHeaderAtEraId {
era_id: EraId,
responder: Responder<Option<BlockHeader>>,
},
GetSwitchBlockAtEraId {
era_id: EraId,
responder: Responder<Option<Block>>,
},
GetBlockHeaderForDeploy {
deploy_hash: DeployHash,
responder: Responder<Option<BlockHeader>>,
},
GetHighestSwitchBlock {
responder: Responder<Option<Block>>,
},
GetBlockHeader {
block_hash: BlockHash,
responder: Responder<Option<BlockHeader>>,
},
GetBlockTransfers {
block_hash: BlockHash,
responder: Responder<Option<Vec<Transfer>>>,
},
PutDeploy {
deploy: Box<Deploy>,
responder: Responder<bool>,
},
GetDeploys {
deploy_hashes: Vec<DeployHash>,
responder: Responder<Vec<Option<Deploy>>>,
},
GetDeployHeaders {
deploy_hashes: Vec<DeployHash>,
responder: Responder<Vec<Option<DeployHeader>>>,
},
GetFinalizedDeploys {
ttl: TimeDiff,
responder: Responder<Vec<(DeployHash, DeployHeader)>>,
},
PutExecutionResults {
block_hash: Box<BlockHash>,
execution_results: HashMap<DeployHash, ExecutionResult>,
responder: Responder<()>,
},
GetDeployAndMetadata {
deploy_hash: DeployHash,
responder: Responder<Option<(Deploy, DeployMetadata)>>,
},
GetBlockAndMetadataByHash {
block_hash: BlockHash,
responder: Responder<Option<(Block, BlockSignatures)>>,
},
GetBlockAndMetadataByHeight {
block_height: u64,
responder: Responder<Option<(Block, BlockSignatures)>>,
},
GetHighestBlockWithMetadata {
responder: Responder<Option<(Block, BlockSignatures)>>,
},
GetBlockSignatures {
block_hash: BlockHash,
responder: Responder<Option<BlockSignatures>>,
},
PutBlockSignatures {
signatures: BlockSignatures,
responder: Responder<bool>,
},
}Expand description
A storage request.
Variants
Store given block.
Fields of PutBlock
Retrieve block with given hash.
Fields of GetBlock
Retrieve block header with given height.
Fields of GetBlockHeaderAtHeight
Retrieve block with given height.
Fields of GetBlockAtHeight
Retrieve highest block.
Retrieve switch block header with given era ID.
Fields of GetSwitchBlockHeaderAtEraId
Retrieve switch block with given era ID.
Fields of GetSwitchBlockAtEraId
Retrieve the header of the block containing the deploy.
Fields of GetBlockHeaderForDeploy
Retrieve highest switch block.
Retrieve block header with given hash.
Fields of GetBlockHeader
block_hash: BlockHashHash of block to get header of.
responder: Responder<Option<BlockHeader>>Responder to call with the result. Returns None is the block header doesn’t exist in
local storage.
Retrieve all transfers in a block with given hash.
Fields of GetBlockTransfers
Store given deploy.
Fields of PutDeploy
Retrieve deploys with given hashes.
Fields of GetDeploys
Retrieve deploy headers with given hashes.
Fields of GetDeployHeaders
deploy_hashes: Vec<DeployHash>Hashes of deploy headers to be retrieved.
responder: Responder<Vec<Option<DeployHeader>>>Responder to call with the results.
Retrieve deploys that are finalized and whose TTL hasn’t expired yet.
Fields of GetFinalizedDeploys
ttl: TimeDiffMaximum TTL of block we’re interested in. I.e. we don’t want deploys from blocks that are older than this.
responder: Responder<Vec<(DeployHash, DeployHeader)>>Responder to call with the results.
Store execution results for a set of deploys of a single block.
Will return a fatal error if there are already execution results known for a specific deploy/block combination and a different result is inserted.
Inserting the same block/deploy combination multiple times with the same execution results is not an error and will silently be ignored.
Fields of PutExecutionResults
block_hash: Box<BlockHash>Hash of block.
execution_results: HashMap<DeployHash, ExecutionResult>Mapping of deploys to execution results of the block.
responder: Responder<()>Responder to call when done storing.
Retrieve deploy and its metadata.
Fields of GetDeployAndMetadata
deploy_hash: DeployHashHash of deploy to be retrieved.
responder: Responder<Option<(Deploy, DeployMetadata)>>Responder to call with the results.
Retrieve block and its metadata by its hash.
Fields of GetBlockAndMetadataByHash
Retrieve block and its metadata at a given height.
Fields of GetBlockAndMetadataByHeight
Get the highest block and its metadata.
Fields of GetHighestBlockWithMetadata
Get finality signatures for a Block hash.
Fields of GetBlockSignatures
block_hash: BlockHashThe hash for the request
responder: Responder<Option<BlockSignatures>>Responder to call with the result.
Store finality signatures.
Fields of PutBlockSignatures
signatures: BlockSignaturesSignatures that are to be stored.
responder: Responder<bool>Responder to call with the result, if true then the signatures were successfully stored.