[−][src]Enum casper_node::effect::requests::StorageRequest
A storage request.
Variants
Store given block.
Fields of PutBlock
Retrieve block with given hash.
Fields of GetBlock
Retrieve block with given height.
Fields of GetBlockAtHeight
Retrieve highest block.
Retrieve block header with given hash.
Fields of GetBlockHeader
Store given deploy.
Fields of PutDeploy
Retrieve deploys with given hashes.
Fields of GetDeploys
Retrieve deploy headers with given hashes.
Fields of GetDeployHeaders
Store the given execution results for the deploys in the given block.
Fields of PutExecutionResults
block_hash: <S::Block as Value>::IdHash of block.
execution_results: HashMap<<S::Deploy as Value>::Id, ExecutionResult>Execution results.
responder: Responder<()>Responder to call with the result. Returns true if the execution results were stored on this attempt or false if they were previously stored.
Retrieve deploy and its metadata.
Fields of GetDeployAndMetadata
Store given chainspec.
Fields of PutChainspec
Retrieve chainspec with given version.
Fields of GetChainspec