Trait casper_node::effect::EffectExt [−][src]
pub trait EffectExt: Future + Send { fn event<U, F>(self, f: F) -> Effects<U>
where
F: FnOnce(Self::Output) -> U + 'static + Send,
U: 'static,
Self: Sized; fn events<U, F, I>(self, f: F) -> Effects<U>
where
F: FnOnce(Self::Output) -> I + 'static + Send,
U: 'static,
I: Iterator<Item = U>,
Self: Sized; fn ignore<Ev>(self) -> Effects<Ev>; }
Effect extension for futures, used to convert futures into actual effects.
Required methods
Finalizes a future into an effect that returns a single event.
The function f is used to translate the returned value from an effect into an event.
Finalizes a future into an effect that returns an iterator of events.
The function f is used to translate the returned value from an effect into an iterator of
events.