Function casper_node::migrate_config [−][src]
pub fn migrate_config(
_old_config: WithDir<Config>,
_new_config: WithDir<Config>
) -> Result<(), Error>
Migrates values from the old config file to the new one, modifying the new config file on-disk.
This should be executed after a new version is available, but before the casper-node has been run in validator mode using the new version.