Function casper_node::migrate_data [−][src]
pub fn migrate_data(
_old_config: WithDir<Value>,
new_config: WithDir<Config>
) -> Result<(), Error>
Migrates data from that specified in the old config file to that specified in the new one.