Module casper_node::rpcs::docs
source · [−]Expand description
RPCs related to finding information about currently supported RPCs.
Structs
An example pair of request params and response result.
“rpc.discover” RPC.
Result for “rpc.discover” RPC response.
The struct containing the documentation for the RPCs.
The main schema for the casper node’s RPC server, compliant with the OpenRPC Specification.
Traits
A trait used to generate a static hardcoded example of Self.