[][src]Module casper_node::rpcs::docs

RPCs related to finding information about currently supported RPCs.

Structs

Example

An example pair of request params and response result.

ListRpcs

"rpc.discover" RPC.

ListRpcsResult

Result for "rpc.discover" RPC response.

Method

The struct containing the documentation for the RPCs.

Traits

DocExample

A trait used to generate a static hardcoded example of Self.