Module casper_node::types[][src]

Common types used across multiple components.

Re-exports

pub use chainspec::Chainspec;

Modules

The chainspec is a set of configuration options for the network. All validators must apply the same set of options in order to join and act as a peer in a given network.

Types which are serializable to JSON, which map to types defined outside this module.

Structs

A struct containing a signature and the public key of the signer.

A proto-block after execution, with the resulting post-state-hash. This is the core component of the Casper linear blockchain.

The body portion of a block.

A cryptographic hash identifying a Block.

The header portion of a Block.

A storage representation of finality signatures with the associated block hash.

Summary information from the chainspec.

A deploy; an item containing a smart contract along with the requester’s signature(s).

The cryptographic hash of a Deploy.

The header portion of a Deploy.

The deploy mutable metadata.

Error returned when a Deploy is too large.

A validator’s signature of a block, to confirm it is finalized. Clients and joining nodes should wait until the signers’ combined weight exceeds their fault tolerance threshold before accepting the block as finalized.

Result for “info_get_status” RPC response.

A JSON-friendly representation of Block.

Node configuration.

Map of peer IDs to network addresses.

Data feed for client “info_get_status” endpoint.

A time difference between two timestamps.

A timestamp type, representing a concrete moment in time.

Enums

An error that can arise when validating a block’s cryptographic integrity using its hashes

Errors other than validation failures relating to Deploys.

The DeployHash stored in a way distinguishing between WASM deploys and transfers.

A representation of the way in which a deploy failed validation checks.

Exit codes which should be used by the casper-node binary, and provided by the initializer reactor to the binary.

An identifier for a specific type implementing the Item trait. Each different implementing type should have a unique Tag variant.

Traits

An object-safe RNG trait that requires a cryptographically strong random number generator.

Indicates that a type knows how to approximate its memory usage.

A trait which allows an implementing type to be used by the gossiper and fetcher components, and furthermore allows generic network messages to include this type due to the provision of the type-identifying TAG.

Type Definitions

The cryptographically secure RNG used throughout the node.

Derive Macros

Automatically derive the DataSize trait for a type.