[−][src]Module casper_node::types
Common types used across multiple components.
Modules
| json_compatibility | Types which are serializable to JSON, and which map to types defined outside this crate. |
Structs
| Approval | A struct containing a signature and the public key of the signer. |
| Block | A proto-block after execution, with the resulting post-state-hash. This is the core component of the Casper linear blockchain. |
| BlockHash | A cryptographic hash identifying a |
| BlockHeader | The header portion of a |
| Deploy | A deploy; an item containing a smart contract along with the requester's signature(s). |
| DeployHash | The cryptographic hash of a |
| DeployHeader | The header portion of a |
| NodeConfig | Node configuration. |
| StatusFeed | Data feed for client "info_get_status" endpoint. |
| TimeDiff | A time difference between two timestamps. |
| Timestamp | A timestamp type, representing a concrete moment in time. |
Enums
| BlockValidationError | An error that can arise when validating a block's cryptographic integrity using its hashes |
| DeployError | Error returned from constructing or validating a |
| Tag | An identifier for a specific type implementing the |
Traits
| CryptoRngCore | An object-safe RNG trait that requires a cryptographically strong random number generator. |
| Item | A trait which allows an implementing type to be used by the gossiper and fetcher components, and
furthermore allows generic network messages to include this type due to the provision of the
type-identifying |