pub enum DeployConfigurationFailure {
Show 17 variants
InvalidChainName {
expected: String,
got: String,
},
ExcessiveDependencies {
max_dependencies: u8,
got: usize,
},
ExcessiveSize(ExcessiveSizeError),
ExcessiveTimeToLive {
max_ttl: TimeDiff,
got: TimeDiff,
},
InvalidBodyHash,
InvalidDeployHash,
EmptyApprovals,
InvalidApproval {
index: usize,
error_msg: String,
},
ExcessiveSessionArgsLength {
max_length: usize,
got: usize,
},
ExcessivePaymentArgsLength {
max_length: usize,
got: usize,
},
MissingPaymentAmount,
FailedToParsePaymentAmount,
ExceededBlockGasLimit {
block_gas_limit: u64,
got: U512,
},
MissingTransferAmount,
FailedToParseTransferAmount,
InsufficientTransferAmount {
minimum: U512,
attempted: U512,
},
ExcessiveApprovals {
got: u32,
max_associated_keys: u32,
},
}Expand description
A representation of the way in which a deploy failed validation checks.
Variants
InvalidChainName
Invalid chain name.
ExcessiveDependencies
Fields
max_dependencies: u8The dependencies limit.
got: usizeThe actual number of dependencies provided.
Too many dependencies.
ExcessiveSize(ExcessiveSizeError)
Deploy is too large.
ExcessiveTimeToLive
Excessive time-to-live.
InvalidBodyHash
The provided body hash does not match the actual hash of the body.
InvalidDeployHash
The provided deploy hash does not match the actual hash of the deploy.
EmptyApprovals
The deploy has no approvals.
InvalidApproval
Fields
index: usizeThe index of the approval at fault.
error_msg: StringThe approval validation error.
Invalid approval.
ExcessiveSessionArgsLength
Fields
max_length: usizeThe byte size limit of session arguments.
got: usizeThe received length of session arguments.
Excessive length of deploy’s session args.
ExcessivePaymentArgsLength
Fields
max_length: usizeThe byte size limit of payment arguments.
got: usizeThe received length of payment arguments.
Excessive length of deploy’s payment args.
MissingPaymentAmount
Missing payment “amount” runtime argument.
FailedToParsePaymentAmount
Failed to parse payment “amount” runtime argument.
ExceededBlockGasLimit
The payment amount associated with the deploy exceeds the block gas limit.
MissingTransferAmount
Missing payment “amount” runtime argument
FailedToParseTransferAmount
Failed to parse transfer “amount” runtime argument.
InsufficientTransferAmount
Insufficient transfer amount.
ExcessiveApprovals
Fields
got: u32Number of approvals on the deploy.
max_associated_keys: u32The chainspec limit for max_associated_keys.
The amount of approvals on the deploy exceeds the max_associated_keys limit.