Module casper_node::types::error
source · [−]Expand description
Errors that may be emitted by methods for common types.
Enums
An error that can arise when creating a block from a finalized block and other components
An error that can arise when validating a block’s cryptographic integrity using its hashes