Trait casper_node::types::Item
source · [−]pub trait Item: Clone + Serialize + DeserializeOwned + Send + Sync + Debug + Display {
type Id: Copy + Eq + Hash + Serialize + DeserializeOwned + Send + Sync + Debug + Display;
const TAG: Tag;
const ID_IS_COMPLETE_ITEM: bool;
fn id(&self) -> Self::Id;
}Expand description
A trait which allows an implementing type to be used by the gossiper and fetcher components, and
furthermore allows generic network messages to include this type due to the provision of the
type-identifying TAG.
Required Associated Types
Required Associated Constants
const ID_IS_COMPLETE_ITEM: bool
const ID_IS_COMPLETE_ITEM: bool
Whether the item’s ID is the complete item or not.