Module casper_node::utils [−][src]
Various functions that are not limited to a particular module, but are too small to warrant being factored out into standalone crates.
Modules
Datasize helper functions.
Load and store milliseconds directly as Duration using serde.
PidFile utility type.
Structs
Error reading a file.
DNS resolution error.
With-directory context.
Error writing a file
Enums
External resource.
An error starting one of the HTTP servers.
Error loading external value.
The source of a piece of data.
Statics
OS page size.
Traits
A value that can be loaded from a file.
Functions
Read complete at path into memory.
Wait until all strong references for a particular arc have been dropped.
XORs two byte sequences.